import cv2
import numpy as np


def byte_to_cv2_rgb(bytes_image: bytes):
    """
    Convert image from byte to cv2
    """
    bytearr_image = bytearray(bytes_image.read())
    image = np.asarray(bytearr_image, dtype=np.uint8)
    cv2_image = cv2.imdecode(image, cv2.IMREAD_COLOR)
    rgb_image = cv2_bgr_to_rgb(cv2_image)
    return rgb_image


def cv2_bgr_to_rgb(cv2_image):
    """
    Convert color order from BGR to RGB
    """
    rgb_image = cv2.cvtColor(cv2_image, cv2.COLOR_BGR2RGB)
    return rgb_image



from sklearn.cluster import KMeans

from majocol.utils import is_positive_int
from majocol.types import HexRgbList


def pick(rgb_image, count: int = 1) -> HexRgbList:
    """
    Pick major colors from image
    """
    if not is_positive_int(count):
        return None

    try:
        image_shape = rgb_image.shape[0] * rgb_image.shape[1]
        img = rgb_image.reshape(image_shape, 3)
    except BaseException:
        return None

    cluster = KMeans(n_clusters=count)
    cluster.fit(X=img)

    centers_arr = cluster.cluster_centers_.astype(int, copy=False)
    colors_hex = []
    for rgb_arr in centers_arr:
        color_hex = '%02x%02x%02x' % tuple(rgb_arr)
        colors_hex.append(color_hex)

    return colors_hex



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['majocol']

package_data = \
{'': ['*']}

install_requires = \
['numpy>=1.19.1,<2.0.0',
 'opencv-python>=4.4.0,<5.0.0',
 'scikit-learn>=0.23.2,<0.24.0']

setup_kwargs = {
    'name': 'majocol',
    'version': '0.1.2',
    'description': 'pick major colors from image',
    'long_description': '<p align="center">\n  <img width="420px" src="https://raw.githubusercontent.com/suzukey/majocol/main/docs/img/majocol.png" alt=\'majocol\'>\n</p>\n\n<p align="center">\n  <em>Pick major colors from image</em>\n</p>\n\n<p align="center">\n  <a href="https://pypi.org/project/majocol/" target="_blank">\n    <img src="https://badge.fury.io/py/majocol.svg" alt="Package version">\n  </a>\n</p>\n\n---\n\n**Documentation**:\n\n---\n\n# MajoCol\n\n## Requirements\n\nPython 3.6+\n\n## Installation\n\n```shell\n$ pip3 install majocol\n```\n\n<p align="center">&mdash; \U0001fa84 &mdash;</p>\n\n<p align="center">\n  <i>MajoCol is licensed under the terms of the <a href="https://github.com/suzukey/majocol/blob/main/LICENSE">MIT license</a>.</i>\n</p>\n',
    'author': 'suzukey',
    'author_email': 'suzukey28@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/suzukey/majocol',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
